@@ -1,4 +1,5 @@
-from checklists.models import Map, Activity, Age, Protocol, Sex
+from checklists.models import Map, Activity, Age, Protocol, Sex, \
+    set_current_user, clear_current_user
 
 activities = (
     ('Birding', 'birding'),
@@ -25,6 +26,7 @@ sexes = (
 
 
 def run():
+    set_current_user('load_map')
 
     Map.objects.all().delete()
 
@@ -43,3 +45,5 @@ def run():
     for name, slug in sexes:
         Map.objects.create(
             name=name, content_object=Sex.objects.get(slug=slug))
+
+    clear_current_user()
